<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>QEyesConfigDialog</name>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="44"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="50"/>
        <source>Number of eyes</source>
        <translation>Число глаз</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="56"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="60"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="65"/>
        <source>Reset</source>
        <translation>Сброс</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="69"/>
        <source>QEyes Settings</source>
        <translation>Настройка QEyes</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="103"/>
        <source>QEyes default</source>
        <translation>Стандартно для QEyes</translation>
    </message>
</context>
</TS>
